@@ -234,9 +234,11 @@ export class TriggerPanelCtrl extends PanelCtrl {
   getTriggers() {
     const timeFrom = Math.ceil(dateMath.parse(this.range.from) / 1000);
     const timeTo = Math.ceil(dateMath.parse(this.range.to) / 1000);
+    const userIsEditor = this.contextSrv.isEditor || this.contextSrv.isGrafanaAdmin;
 
     let promises = _.map(this.panel.datasources, (ds) => {
       let proxies;
+      let showAckButton = true;
       return this.datasourceSrv.get(ds)
       .then(datasource => {
         const zabbix = datasource.zabbix;
@@ -244,6 +246,7 @@ export class TriggerPanelCtrl extends PanelCtrl {
         const triggerFilter = this.panel.targets[ds];
         const showProxy = this.panel.hostProxy;
         const getProxiesPromise = showProxy ? zabbix.getProxies() : () => [];
+        showAckButton = !datasource.disableReadOnlyUsersAck || userIsEditor;
 
         // Replace template variables
         const groupFilter = datasource.replaceTemplateVars(triggerFilter.group.filter);
@@ -271,17 +274,16 @@ export class TriggerPanelCtrl extends PanelCtrl {
         }));
         return Promise.all([
           this.datasources[ds].zabbix.getExtendedEventData(eventids),
-          this.datasources[ds].zabbix.getEventAlerts(eventids),
           Promise.resolve(triggers)
         ]);
       })
-      .then(([events, alerts, triggers]) => {
+      .then(([events, triggers]) => {
         this.addEventTags(events, triggers);
         this.addAcknowledges(events, triggers);
-        this.addEventAlerts(alerts, triggers);
         return triggers;
       })
       .then(triggers => this.setMaintenanceStatus(triggers))
+      .then(triggers => this.setAckButtonStatus(triggers, showAckButton))
       .then(triggers => this.filterTriggersPre(triggers, ds))
       .then(triggers => this.addTriggerDataSource(triggers, ds))
       .then(triggers => this.addTriggerHostProxy(triggers, proxies));
@@ -337,18 +339,6 @@ export class TriggerPanelCtrl extends PanelCtrl {
     return triggers;
   }
 
-  addEventAlerts(alerts, triggers) {
-    alerts.forEach(alert => {
-      const trigger = _.find(triggers, t => {
-        return t.lastEvent && alert.eventid === t.lastEvent.eventid;
-      });
-      if (trigger) {
-        trigger.alerts = trigger.alerts ? trigger.alerts.concat(alert) : [alert];
-      }
-    });
-    return triggers;
-  }
-
   filterTriggersPre(triggerList, ds) {
     // Filter triggers by description
     let triggerFilter = this.panel.targets[ds].trigger.filter;
@@ -409,6 +399,13 @@ export class TriggerPanelCtrl extends PanelCtrl {
     return triggers;
   }
 
+  setAckButtonStatus(triggers, showAckButton) {
+    _.each(triggers, (trigger) => {
+      trigger.showAckButton = showAckButton;
+    });
+    return triggers;
+  }
+
   addTriggerDataSource(triggers, ds) {
     _.each(triggers, (trigger) => {
       trigger.datasource = ds;
@@ -503,16 +500,27 @@ export class TriggerPanelCtrl extends PanelCtrl {
     this.refresh();
   }
 
-  getProblemEvents(trigger) {
-    const triggerids = [trigger.triggerid];
+  getProblemEvents(problem) {
+    const triggerids = [problem.triggerid];
     const timeFrom = Math.ceil(dateMath.parse(this.range.from) / 1000);
     const timeTo = Math.ceil(dateMath.parse(this.range.to) / 1000);
-    return this.datasourceSrv.get(trigger.datasource)
+    return this.datasourceSrv.get(problem.datasource)
     .then(datasource => {
       return datasource.zabbix.getEvents(triggerids, timeFrom, timeTo, [0, 1], PROBLEM_EVENTS_LIMIT);
     });
   }
 
+  getProblemAlerts(problem) {
+    if (!problem.lastEvent || problem.lastEvent.length === 0) {
+      return Promise.resolve([]);
+    }
+    const eventids = [problem.lastEvent.eventid];
+    return this.datasourceSrv.get(problem.datasource)
+    .then(datasource => {
+      return datasource.zabbix.getEventAlerts(eventids);
+    });
+  }
+
   formatHostName(trigger) {
     let host = "";
     if (this.panel.hostField && this.panel.hostTechNameField) {
@@ -663,6 +671,7 @@ export class TriggerPanelCtrl extends PanelCtrl {
         pageSize,
         fontSize: fontSizeProp,
         getProblemEvents: ctrl.getProblemEvents.bind(ctrl),
+        getProblemAlerts: ctrl.getProblemAlerts.bind(ctrl),
         onPageSizeChange: ctrl.handlePageSizeChange.bind(ctrl),
         onColumnResize: ctrl.handleColumnResize.bind(ctrl),
         onProblemAck: (trigger, data) => {
